pub enum PickEntity {
Structure(GlobalPickIdentity),
VolumeSegment(VolumeSegmentRef),
}Expand description
The two identity domains that can be visible in a frame.
Variants
Structure(GlobalPickIdentity)
A molecular entity from the opaque or transparent structural path.
VolumeSegment(VolumeSegmentRef)
A caller-supplied categorical volume label.