pub enum TransferFunction {
Srgb,
Linear,
Pq,
Hlg,
}Expand description
Transfer curve used to encode the selected display gamut.
Variants
Srgb
Standard dynamic-range sRGB electro-optical transfer curve.
Linear
Linear values for callers that own the final encoding.
Pq
SMPTE ST 2084 perceptual quantizer for HDR output.
Hlg
Hybrid Log-Gamma scene-referred HDR transfer curve.