pub struct ChunkPlacementId(/* private fields */);Expand description
Caller identity for one independently mutable spatial chunk occurrence. Stable caller identity for one spatial occurrence of a resident chunk.
A chunk can be drawn more than once with distinct transforms or shared templates. Spatial relations therefore address an occurrence as well as a dataset, chunk and logical row.
Implementations