pub struct SequenceConfig {
pub image: ImageConfig,
pub timebase_nanoseconds: u64,
pub max_in_flight: u8,
}Expand description
Fixed output and readback limits for one deterministic frame sequence.
Fields
image: ImageConfigDimensions shared by every frame.
timebase_nanoseconds: u64Nanoseconds represented by one timestamp tick.
max_in_flight: u8Bounded number of submitted frames awaiting readback.
Implementations
Sourceimpl SequenceConfig
impl SequenceConfig
Sourcepub fn at_fps(
image: ImageConfig,
frames_per_second: u32,
max_in_flight: u8,
) -> Result<Self, RenderError>
pub fn at_fps( image: ImageConfig, frames_per_second: u32, max_in_flight: u8, ) -> Result<Self, RenderError>
Creates a nanosecond timebase for a fixed integer frame rate.
Errors
Rejects zero frame rates and rates that do not map to a positive integral nanosecond interval.