pub struct BondChunkPlacement {
pub id: ChunkPlacementId,
pub ticket: ResidencyTicket,
pub model_to_world: Mat4,
pub radius: f32,
pub color: Rgba8,
}Expand description
Declarative analytic rendering of one resident provider bond chunk.
Fields
id: ChunkPlacementIdStable placement identity in the shared bounded placement table.
ticket: ResidencyTicketExact resident bond generation to draw.
model_to_world: Mat4Atom-dataset coordinates to world space.
radius: f32Analytic cylinder radius in local coordinate units.
color: Rgba8Uniform packed display color.
Implementations
Sourceimpl BondChunkPlacement
impl BondChunkPlacement
Sourcepub fn licorice(
id: ChunkPlacementId,
ticket: ResidencyTicket,
model_to_world: Mat4,
radius: f32,
color: Rgba8,
) -> Result<Self, ChunkPlacementError>
pub fn licorice( id: ChunkPlacementId, ticket: ResidencyTicket, model_to_world: Mat4, radius: f32, color: Rgba8, ) -> Result<Self, ChunkPlacementError>
Creates a licorice-style analytic cylinder placement.
Ball-and-stick is composed by declaring this placement together with space-filling atom placements; both reference the same coordinate arena.
Errors
Rejects a non-finite transform or a non-positive/non-finite radius.